#pragma once

/*
 * Chap1TransformFeedback.h - Version 1.0 - May 22, 2020.
 *
 * Author: Sam Buss
 *
 * Software accompanying POSSIBLE SECOND EDITION TO the book
 *		3D Computer Graphics: A Mathematical Introduction with OpenGL,
 *		by S. Buss, Cambridge University Press, 2003.
 *
 * Software is "as-is" and carries no warranty.  It may be used without
 *   restriction, but if you modify it, please change the filenames to
 *   prevent confusion between different versions.
 * Bug reports: Sam Buss, sbuss@ucsd.edu.
 * Web page: http://math.ucsd.edu/~sbuss/MathCG2
 */

// Use the static library (so glew32.dll is not needed):
#define GLEW_STATIC

#include <GL/glew.h> 
#include <GLFW/glfw3.h>

class LinearMapR4;      // Used in the function prototypes, declared in LinearMapR4.h

//
// External variables.  Can be be used by other .cpp files.
// These external variables are set mostly in LetterProj.cpp,
//    and many of them are used in MyInitial.cpp to control the rendering.
// The external declarations do not give the initial values:
//    Initial values are set with their declaration in LetterPrj.cpp
//

// These two variables control how triangles are rendered.
extern bool wireframeMode;	// Equals true for polygon GL_FILL mode. False for polygon GL_LINE mode.
extern bool cullBackFaces;   // Equals true to cull backfaces. Equals false to not cull backfaces. 

extern LinearMapR4 viewMatrix;		// The current view matrix, based on viewAzimuth and viewDirection.
// Comment: It might be a better design to have two matrices --- a view matrix and model matrix;
//     and have the vertex shader multiply them together; however, it is left as a single matrix for 
//     simplicity and for consistency with Math 155A Project #2.

extern float matEntries[16];	// Holds 16 floats (since cannot load doubles into a shader that uses floats)

// ***********************
// Function prototypes
// By declaring function prototypes here, they can be defined in any order desired in the .cpp file.
// ******
bool check_for_opengl_errors();     

void mySetupFloorGeometry();      
void mySetupGeometries();
void mySetViewMatrix();  
void MyRemeshGeometries();

void myRenderScene();
void MyRenderFloor();
void MyRenderGeometries();
void RenderSceneForFeedback();

void SetCurrentShader(int shaderNum);

void my_setup_SceneData();
void my_setup_OpenGL();
void key_callback(GLFWwindow* window, int key, int scancode, int action, int mods);
void window_size_callback(GLFWwindow* window, int width, int height);
void error_callback(int error, const char* description);
void setup_callbacks(GLFWwindow* window);